@@ -10,11 +10,10 @@ def main():
     # check config availability and load configuration
     try:
         config_fobject = open(config.default_filename)
-    except (IOError, OSError), e:
+    except (IOError, OSError) as e:
         util.report_error("Cannot load configuration (%s) -- run configleecher first" % (e))
         sys.exit(7)
     cfg = config.load_config(config_fobject)
-    local_download_dir = cfg.general.local_download_dir
     client = config.get_client(cfg)
 
     # separate the wheat from the chaff
@@ -27,7 +26,10 @@ def main():
     for uploadable in args.torrents:
         try:
             if type(uploadable) is str:
-                uploadable = uploadable.decode(sys.stdout.encoding)
+                try:
+                    uploadable = uploadable.decode(sys.getfilesystemencoding())
+                except AttributeError:
+                    pass
             if is_magnet(uploadable):
                 client.upload_magnet_link(uploadable)
                 util.report_message("%s submitted to seedbox" % uploadable)
